@@ -219,7 +219,7 @@ def test_cli_with_multiple_index_url_and_tilde_req_with_max_rounds():
 @pytest.mark.online
 def test_cli_with_multiple_index_url_and_tilde_req_and_netrc_file_without_matching_url():
     expected_file = test_env.get_test_loc("tilde_req-expected.json", must_exist=False)
-    netrc_file = test_env.get_test_loc("test.netrc", must_exist=False)
+    netrc_file = test_env.get_test_loc("test-commented.netrc", must_exist=False)
     specifier = "zipp~=3.8.0"
     extra_options = [
         "--index-url",
@@ -373,7 +373,7 @@ def test_passing_of_json_pdt_and_json_flags():
 def test_version_option():
     options = ["--version"]
     result = run_cli(options=options)
-    assert "0.9.4" in result.output
+    assert "0.9.5" in result.output
 
 
 def test_passing_of_netrc_file_that_does_not_exist():
